Blob Blame History Raw
diff -up argyllcms-0.70/ttbd.txt.BAD argyllcms-0.70/ttbd.txt
--- argyllcms-0.70/ttbd.txt.BAD	2008-03-26 16:17:18.000000000 -0400
+++ argyllcms-0.70/ttbd.txt	2008-03-26 16:17:39.000000000 -0400
@@ -325,7 +325,7 @@ Categories:
   patch variance is too high (probable faulty read).
 
 * Add spectral fix options to scanin code to allow compensation
-  for scanner and media errors when using a scanner as a colorimeter.
+  for media errors when using an image as a colorimeter.
   This means figuring out how it will work, as well as creating
   to tools to create the spectral fix data (or just add general
   tweak/abstract profile support ?).
diff -up argyllcms-0.70/doc/Organisation.html.BAD argyllcms-0.70/doc/Organisation.html
--- argyllcms-0.70/doc/Organisation.html.BAD	2008-03-26 16:16:28.000000000 -0400
+++ argyllcms-0.70/doc/Organisation.html	2008-03-26 16:16:42.000000000 -0400
@@ -150,7 +150,7 @@ and output the patch values using the CG
 is
 used to get the patch information from a scan of an IT8 calibration
 chart.
-It also has a mode to use the scanner as a crude colorimeter, and
+It also has a mode to use an image as a crude colorimeter, and
 convert
 a print test chart into approximate CIE values.<br>
 <br>
diff -up argyllcms-0.70/doc/scanin.html.BAD argyllcms-0.70/doc/scanin.html
--- argyllcms-0.70/doc/scanin.html.BAD	2008-03-26 16:11:39.000000000 -0400
+++ argyllcms-0.70/doc/scanin.html	2008-03-26 16:11:42.000000000 -0400
@@ -70,7 +70,7 @@ Output patch values in .val file</span><
 <span style="font-family: monospace;">&nbsp;</span><a
  style="font-family: monospace;" href="#c">-c</a><span
  style="font-family: monospace;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-Use scanner as colorimeter to</span><br style="font-family: monospace;">
+Use an image as colorimeter to</span><br style="font-family: monospace;">
 <span style="font-family: monospace;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
 convert printer .ti2 to .ti3</span><br style="font-family: monospace;">
 <span style="font-family: monospace;">&nbsp;</span><a
@@ -184,7 +184,7 @@ before submitting the file to scanin.<br
 There are 5 basic modes that <b>scanin</b> operates in.<br>
 <ul>
   <li><a name="_"></a>When no special argument is given scanin is
-assumed to be scanning an input device characterization chart (ie. an
+assumed to be parsing an input device characterization chart (ie. an
 IT8.7/2 chart), for the purpose of creating a <a
  href="File_Formats.html#.ti3">.ti3</a> data file containing
 the CIE test values and the corresponding RGB scanner values. The <a
@@ -226,22 +226,18 @@ are: <a name="op1"></a>The TIFF file tha
 to be created, <a name="op3"></a>and an optional name for the image
 recognition diagnostic
 output.</li>
-  <li><a name="c"></a>If the <b>-c</b> flag is used, then the scanned
-file can be used
+  <li><a name="c"></a>If the <b>-c</b> flag is used, then an image
+file containing a print test chart can be used
 in combination with an input profile, to estimate the CIE tristimulus
-values represented by the scanned patch values. This allows an RGB
-scanner to be used as a "poor mans" colorimeter. The icc profile has
-(presumably) been
-created by scanning an IT8.7/2 chart (or similar) through the scanner,
-and
+values represented by the scanned patch values. The icc profile has
+(presumably) been created with an image of a IT8.7/2 chart (or similar),
 then using scanin to create the .ti3 file needed to feed to profile to
-create
-the scanner profile. The file arguments in -c mode are: <a name="cp1"></a>The
-TIFF file that
-is to be processed containing a scanned image of a print test chart, <a
- name="cp2"></a>the image recognition template file for the test chart
-generated by the <a href="printtarg.html"> printtarg</a> utility, <a
- name="cp3"></a>the scanner ICC profile, <a name="cp4"></a>the base
+create the final profile. The file arguments in -c mode are: 
+<a name="cp1"></a>The TIFF file that is to be processed containing an 
+image of a print test chart, <a name="cp2"></a>the image recognition 
+template file for the test chart generated by the 
+<a href="printtarg.html"> printtarg</a> utility, <a
+ name="cp3"></a>the ICC profile, <a name="cp4"></a>the base
 name for the .ti2 file containing the
 test chart printer device
 values and their patch identifiers and the base name for the resulting
@@ -251,7 +247,7 @@ recognition diagnostic output.
 The resulting .ti3 file will have the same base name as the input TIFF
 file.
 If there is more than one page in the test chart, then scanin will need
-to be run multiple times, once for each scan file made from each test
+to be run multiple times, once for each file made from each test
 chart. <a name="ca"></a>The <b>-ca</b> flag combination should be
 used
 for all pages after the first,
diff -up argyllcms-0.70/target/printtarg.c.BAD argyllcms-0.70/target/printtarg.c
--- argyllcms-0.70/target/printtarg.c.BAD	2008-03-26 16:12:44.000000000 -0400
+++ argyllcms-0.70/target/printtarg.c	2008-03-26 16:18:29.000000000 -0400
@@ -1968,7 +1968,7 @@ int *p_npat			/* Return number of patche
 						}
 					}
 
-					/* If we are anticipating scanner input, create the */
+					/* If we need it, create the */
 					/* scanner recognition file for this page. */
 					if (scanc & 1) {
 						char chtname[200];	/* Name of .cht file */
@@ -2761,7 +2761,7 @@ char *argv[];
 }
 
 /******************************************************************/
-/* Edge tracking support, for generating the scanner image        */
+/* Edge tracking support, for generating the image        */
 /* recognition reference chart file. */
 
 /* Establish width and height to convert between topleft and */
diff -up argyllcms-0.70/scanin/scanin.c.BAD argyllcms-0.70/scanin/scanin.c
--- argyllcms-0.70/scanin/scanin.c.BAD	2008-03-26 16:01:47.000000000 -0400
+++ argyllcms-0.70/scanin/scanin.c	2008-03-26 16:10:27.000000000 -0400
@@ -87,7 +87,7 @@ usage(void) {
 	fprintf(stderr,"\n");
 	fprintf(stderr," -g                   Generate a chart reference (.cht) file\n");
 	fprintf(stderr," -o                   Output patch values in .val file\n");
-	fprintf(stderr," -c                   Use scanner as colorimeter to\n");
+	fprintf(stderr," -c                   Use an image as colorimeter to\n");
 	fprintf(stderr,"                       convert printer .ti2 to .ti3\n");
 	fprintf(stderr," -ca                  Same as -c, but accumulates more values to .ti3\n");
 	fprintf(stderr,"                       from subsequent pages\n");
@@ -129,7 +129,7 @@ int main(int argc, char *argv[])
 	int tmean = 0;		/* Return true mean, rather than robust mean */
 	int repl = 0;		/* Replace .ti3 device values from raster file */
 	int outo = 0;		/* Output the values read, rather than creating scanner .ti3 */
-	int colm = 0;		/* Use scan values as colorimter for print profile. > 1 == append */
+	int colm = 0;		/* Use image values as colorimeter for print profile. > 1 == append */
 	int flags = SI_GENERAL_ROT;	/* Default allow all rotations */
 
 	TIFF *rh = NULL, *wh = NULL;
@@ -318,7 +318,7 @@ int main(int argc, char *argv[])
 			/* Data file */
 			strcpy(datin_name,argv[fa]);
 		}
-		if (repl != 0 || colm > 0) {	/* Colorimter emulation or replacing .ti3 device data */
+		if (repl != 0 || colm > 0) {	/* Colorimeter emulation or replacing .ti3 device data */
 			strcpy(datin_name,argv[fa]);
 			strcat(datin_name,".ti2");
 			strcpy(datout_name,argv[fa]);
@@ -652,11 +652,11 @@ int main(int argc, char *argv[])
 			icg->del(icg);		/* Clean up */
 
 		/* ---------------------------------------------------------- */
-		} else if (colm > 0) {	/* Using the scanner as a colorimeter */
+		} else if (colm > 0) {	/* Using an image as a colorimeter */
 			/* All this needs to track the code in spectro/printread.c */
 			cgats *icg;			/* input .ti2 cgats structure */
 			cgats *ocg;			/* input/output .ti3 cgats structure */
-			icmFile *rd_fp;		/* Scanner to CIE lookup */
+			icmFile *rd_fp;		/* Image to CIE lookup */
 			icc *rd_icco;
 			icmLuBase *luo;
 			time_t clk = time(0);
@@ -870,7 +870,7 @@ int main(int argc, char *argv[])
 			} else
 				error ("Input file keyword COLOR_REPS has unknown value");
 		
-			/* Setup scanner RGB to XYZ conversion */
+			/* Setup RGB to XYZ conversion */
 			{
 				int inn, outn;			/* Chanels for input and output spaces */
 				icColorSpaceSignature ins, outs;	/* Type of input and output spaces */